/*
** Module   : RadioSetInterface.java
** Abstract : Define all RADIO-SET widget-related APIs available via a widget handle instance
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -------Description-----------------------------
** 001 IAS 20150212        Created initial version.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

public interface RadioSetInterface 
{
   /**
    * Resets the value of the HORIZONTAL attribute for radio-set.
    * 
    * @param   value
    *          The new value of the HORIZONTAL attribute.
    */
   @LegacyAttribute(name = "HORIZONTAL", setter = true)
   public void setHorizontal(boolean value);

   /**
    * Resets the value of the HORIZONTAL attribute for radio-set.
    * 
    * @param   value
    *          The new value of the HORIZONTAL attribute.
    */
   @LegacyAttribute(name = "HORIZONTAL", setter = true)
   public void setHorizontal(logical value);
   
   /**
    * Get the value of the HORIZONTAL attribute for radio-set.
    * 
    * @return
    *          The new value of the HORIZONTAL attribute.
    */
   @LegacyAttribute(name = "HORIZONTAL")
   public logical isHorizontal();

   /**
    * Resets the value of the EXPAND attribute for radio-set.
    * 
    * @param   value
    *          The new value of the HORIZONTAL attribute.
    */
   @LegacyAttribute(name = "EXPAND", setter = true)
   public void setExpand(boolean value);

   /**
    * Resets the value of the EXPAND attribute for radio-set.
    * 
    * @param   value
    *          The new value of the HORIZONTAL attribute.
    */
   @LegacyAttribute(name = "EXPAND", setter = true)
   public void setExpand(logical value);
   
   /**
    * Get the value of the EXPAND attribute for radio-set.
    * 
    * @return
    *          The value of the EXPAND attribute.
    */
   @LegacyAttribute(name = "EXPAND")
   public logical isExpand();

   /**
    * Get RADIO-BUTTONS attribute.
    * 
    * @return  Current value of the attribute.
    */
   @LegacyAttribute(name = "RADIO-BUTTONS")
   public character getRadioButtons();
   
   /**
    * Set RADIO-BUTTONS attribute. The parameter contains string
    * representation of all radio button labels and values separated by
    * delimiter (comma is the default value).
    * <p>
    * Example: <code>Label1,value1,Label2,value2,..., LabelN,valueN</code>
    * 
    * @param   c
    *          New value of the attribute.
    */
   @LegacyAttribute(name = "RADIO-BUTTONS", setter = true)
   public void setRadioButtons(character c);

   /**
    * Set RADIO-BUTTONS attribute. The parameter contains string
    * representation of all radio button labels and values separated by
    * delimiter (comma is the default value).
    * <p>
    * Example: <code>Label1,value1,Label2,value2,..., LabelN,valueN</code>
    * 
    * @param   c
    *          New value of the attribute.
    */
   @LegacyAttribute(name = "RADIO-BUTTONS", setter = true)
   public void setRadioButtons(String c);


}
